"""
Dirac Hashes - Quantum-inspired cryptographic hash functions.

This package provides quantum-inspired hash functions and key generation
algorithms designed to be resistant to quantum computing attacks.
"""

__version__ = '0.1.0'
__author__ = 'Quantum Hash Team'
__email__ = 'example@example.com'
__license__ = 'MIT'

# Expose key classes and functions at package level
from quantum_hash.dirac import DiracHash 